@@ -5,10 +5,12 @@ import os
 
 def q1(qn=0):
     if not qn:
-        print(sorted(contents('pm20_5.qu1')))
+        print(sorted(contents('pm20_5')))
+        p = os.path.join('pm20_5', 'qu1')
+        print(p)
         with path(
-                'pm20_5',
-                'qu1.q1_task1'
+                p,
+                'q1_task1.png'
                 ) as pt:
             img = Image(filename=pt)
             display(img)
